@@ -1,4 +1,4 @@
-from utils import features_segmenter, features_pos, preprocess
+from nlpashto.utils import features_segmenter, features_pos, preprocess
 import pickle, os
 
 def word_tokenizer(text):
